translate.storage.po

Package translate :: Package storage :: Module po |
[hide private]
[frames] | no frames]

# Module po

source code

A class loader that will load C or Python implementations of the PO class depending on the USECPO variable.

Use the environment variable USECPO=2 (or 1) to choose the C implementation which uses Gettext's libgettextpo for high parsing speed. Otherise the local Python based parser is used (slower but very well tested).

Imports: logging, Union, c_wchar, CFUNCTYPE, byref, pointer, alignment, c_longlong, tempfile, c_short, oledll, pypo, HRESULT, c_ulong, c_int, WinError, xerror2_prototype, memmove, c_wchar_p, ArgumentError, c_buffer, po_message, cdll, memset, string_at, sizeof, WINFUNCTYPE, xerror2_cb, create_string_buffer, c_double, xerror_handler, create_unicode_buffer, c_long, c_char_p, ctypes, LittleEndianStructure, RTLD_LOCAL, c_ushort, py_object, wstring_at, StringIO, xerror_cb, set_conversion_mode, PyDLL, os, DEFAULT_MODE, names, gpo, WinDLL, DllCanUnloadNow, gestalt, ARRAY, xerror_prototype, OleDLL, CDLL, c_ubyte, RTLD_GLOBAL, c_char, c_float, SetPointerType, resize, cast, get_libgettextpo_version, c_int8, po_xerror_handler, c_byte, GetLastError, c_ulonglong, windll, c_voidp, pythonapi, PYFUNCTYPE, BigEndianStructure, po_error_handler, pydll, Structure, STRING, c_uint, sys, c_void_p, FormatError, c_size_t, c_uint8, DllGetClassObject, addressof, LibraryLoader, Array, POINTER, cStringIO, is_null, extractstr, pounit, po_unescape_map, extractpoline, quoteforpo, unquotefrompo, re, encodingToUse, escapeforpo, quote, textwrap, multistring, copy, data, wrapline, poparser, pofile, base, lsep, unescapehandler, po_escape_map, pocommon